{-# OPTIONS_GHC -fno-warn-deprecations #-}
-- |
-- Stability: deprecated
module Test.Hspec.Formatters
{-# DEPRECATED "Use [Test.Hspec.Api.Formatters.V1](https://hackage.haskell.org/package/hspec-api/docs/Test-Hspec-Api-Formatters-V1.html) instead." #-}
(module Test.Hspec.Core.Formatters.V1)
where
import           Test.Hspec.Core.Formatters.V1
